"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import th2_grpc_lw_data_provider.lw_data_provider_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class MessageGroupsQueueSearchRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class BookGroups(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        BOOK_ID_FIELD_NUMBER: builtins.int
        GROUP_FIELD_NUMBER: builtins.int
        @property
        def book_id(self) -> th2_grpc_lw_data_provider.lw_data_provider_pb2.BookId: ...
        @property
        def group(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[th2_grpc_lw_data_provider.lw_data_provider_pb2.MessageGroupsSearchRequest.Group]: ...
        def __init__(self,
            *,
            book_id: typing.Optional[th2_grpc_lw_data_provider.lw_data_provider_pb2.BookId] = ...,
            group: typing.Optional[typing.Iterable[th2_grpc_lw_data_provider.lw_data_provider_pb2.MessageGroupsSearchRequest.Group]] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["book_id",b"book_id"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["book_id",b"book_id","group",b"group"]) -> None: ...

    START_TIMESTAMP_FIELD_NUMBER: builtins.int
    END_TIMESTAMP_FIELD_NUMBER: builtins.int
    MESSAGE_GROUP_FIELD_NUMBER: builtins.int
    SYNC_INTERVAL_FIELD_NUMBER: builtins.int
    EXTERNAL_QUEUE_FIELD_NUMBER: builtins.int
    KEEP_ALIVE_FIELD_NUMBER: builtins.int
    SEND_RAW_DIRECTLY_FIELD_NUMBER: builtins.int
    RAW_ONLY_FIELD_NUMBER: builtins.int
    @property
    def start_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def end_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def message_group(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MessageGroupsQueueSearchRequest.BookGroups]: ...
    @property
    def sync_interval(self) -> google.protobuf.duration_pb2.Duration: ...
    external_queue: typing.Text
    keep_alive: builtins.bool
    send_raw_directly: builtins.bool
    """*
    Enables sending raw batches directly to external_queue. Sends raw directly first then sends raw to pins
    """

    raw_only: builtins.bool
    """*
    If enabled the message won't be sent to codecs
    """

    def __init__(self,
        *,
        start_timestamp: typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        end_timestamp: typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        message_group: typing.Optional[typing.Iterable[global___MessageGroupsQueueSearchRequest.BookGroups]] = ...,
        sync_interval: typing.Optional[google.protobuf.duration_pb2.Duration] = ...,
        external_queue: typing.Text = ...,
        keep_alive: builtins.bool = ...,
        send_raw_directly: builtins.bool = ...,
        raw_only: builtins.bool = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["end_timestamp",b"end_timestamp","start_timestamp",b"start_timestamp","sync_interval",b"sync_interval"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["end_timestamp",b"end_timestamp","external_queue",b"external_queue","keep_alive",b"keep_alive","message_group",b"message_group","raw_only",b"raw_only","send_raw_directly",b"send_raw_directly","start_timestamp",b"start_timestamp","sync_interval",b"sync_interval"]) -> None: ...
global___MessageGroupsQueueSearchRequest = MessageGroupsQueueSearchRequest

class MessageLoadedStatistic(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class GroupStat(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        BOOK_ID_FIELD_NUMBER: builtins.int
        GROUP_FIELD_NUMBER: builtins.int
        COUNT_FIELD_NUMBER: builtins.int
        @property
        def book_id(self) -> th2_grpc_lw_data_provider.lw_data_provider_pb2.BookId: ...
        @property
        def group(self) -> th2_grpc_lw_data_provider.lw_data_provider_pb2.MessageGroupsSearchRequest.Group: ...
        count: builtins.int
        def __init__(self,
            *,
            book_id: typing.Optional[th2_grpc_lw_data_provider.lw_data_provider_pb2.BookId] = ...,
            group: typing.Optional[th2_grpc_lw_data_provider.lw_data_provider_pb2.MessageGroupsSearchRequest.Group] = ...,
            count: builtins.int = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["book_id",b"book_id","group",b"group"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["book_id",b"book_id","count",b"count","group",b"group"]) -> None: ...

    STAT_FIELD_NUMBER: builtins.int
    @property
    def stat(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MessageLoadedStatistic.GroupStat]: ...
    def __init__(self,
        *,
        stat: typing.Optional[typing.Iterable[global___MessageLoadedStatistic.GroupStat]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["stat",b"stat"]) -> None: ...
global___MessageLoadedStatistic = MessageLoadedStatistic

class EventQueueSearchRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class BookScopes(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        BOOK_ID_FIELD_NUMBER: builtins.int
        SCOPE_FIELD_NUMBER: builtins.int
        @property
        def book_id(self) -> th2_grpc_lw_data_provider.lw_data_provider_pb2.BookId: ...
        @property
        def scope(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[th2_grpc_lw_data_provider.lw_data_provider_pb2.EventScope]: ...
        def __init__(self,
            *,
            book_id: typing.Optional[th2_grpc_lw_data_provider.lw_data_provider_pb2.BookId] = ...,
            scope: typing.Optional[typing.Iterable[th2_grpc_lw_data_provider.lw_data_provider_pb2.EventScope]] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["book_id",b"book_id"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["book_id",b"book_id","scope",b"scope"]) -> None: ...

    START_TIMESTAMP_FIELD_NUMBER: builtins.int
    END_TIMESTAMP_FIELD_NUMBER: builtins.int
    EVENT_SCOPES_FIELD_NUMBER: builtins.int
    SYNC_INTERVAL_FIELD_NUMBER: builtins.int
    EXTERNAL_QUEUE_FIELD_NUMBER: builtins.int
    KEEP_ALIVE_FIELD_NUMBER: builtins.int
    @property
    def start_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def end_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def event_scopes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EventQueueSearchRequest.BookScopes]: ...
    @property
    def sync_interval(self) -> google.protobuf.duration_pb2.Duration: ...
    external_queue: typing.Text
    keep_alive: builtins.bool
    def __init__(self,
        *,
        start_timestamp: typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        end_timestamp: typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        event_scopes: typing.Optional[typing.Iterable[global___EventQueueSearchRequest.BookScopes]] = ...,
        sync_interval: typing.Optional[google.protobuf.duration_pb2.Duration] = ...,
        external_queue: typing.Text = ...,
        keep_alive: builtins.bool = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["end_timestamp",b"end_timestamp","start_timestamp",b"start_timestamp","sync_interval",b"sync_interval"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["end_timestamp",b"end_timestamp","event_scopes",b"event_scopes","external_queue",b"external_queue","keep_alive",b"keep_alive","start_timestamp",b"start_timestamp","sync_interval",b"sync_interval"]) -> None: ...
global___EventQueueSearchRequest = EventQueueSearchRequest

class EventLoadedStatistic(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class ScopeStat(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        BOOK_ID_FIELD_NUMBER: builtins.int
        SCOPE_FIELD_NUMBER: builtins.int
        COUNT_FIELD_NUMBER: builtins.int
        @property
        def book_id(self) -> th2_grpc_lw_data_provider.lw_data_provider_pb2.BookId: ...
        @property
        def scope(self) -> th2_grpc_lw_data_provider.lw_data_provider_pb2.EventScope: ...
        count: builtins.int
        def __init__(self,
            *,
            book_id: typing.Optional[th2_grpc_lw_data_provider.lw_data_provider_pb2.BookId] = ...,
            scope: typing.Optional[th2_grpc_lw_data_provider.lw_data_provider_pb2.EventScope] = ...,
            count: builtins.int = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["book_id",b"book_id","scope",b"scope"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["book_id",b"book_id","count",b"count","scope",b"scope"]) -> None: ...

    STAT_FIELD_NUMBER: builtins.int
    @property
    def stat(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EventLoadedStatistic.ScopeStat]: ...
    def __init__(self,
        *,
        stat: typing.Optional[typing.Iterable[global___EventLoadedStatistic.ScopeStat]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["stat",b"stat"]) -> None: ...
global___EventLoadedStatistic = EventLoadedStatistic



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: th2_grpc_lw_data_provider/queue_data_provider.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from th2_grpc_lw_data_provider import lw_data_provider_pb2 as th2__grpc__lw__data__provider_dot_lw__data__provider__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3th2_grpc_lw_data_provider/queue_data_provider.proto\x12\x14th2.data_provider.lw\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x30th2_grpc_lw_data_provider/lw_data_provider.proto\"\xf8\x03\n\x1fMessageGroupsQueueSearchRequest\x12\x33\n\x0fstart_timestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rend_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12W\n\rmessage_group\x18\x07 \x03(\x0b\x32@.th2.data_provider.lw.MessageGroupsQueueSearchRequest.BookGroups\x12\x30\n\rsync_interval\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x16\n\x0e\x65xternal_queue\x18\x05 \x01(\t\x12\x12\n\nkeep_alive\x18\x06 \x01(\x08\x12\x19\n\x11send_raw_directly\x18\x08 \x01(\x08\x12\x10\n\x08raw_only\x18\t \x01(\x08\x1a\x82\x01\n\nBookGroups\x12-\n\x07\x62ook_id\x18\x01 \x01(\x0b\x32\x1c.th2.data_provider.lw.BookId\x12\x45\n\x05group\x18\x02 \x03(\x0b\x32\x36.th2.data_provider.lw.MessageGroupsSearchRequest.GroupJ\x04\x08\x03\x10\x04\"\xf1\x01\n\x16MessageLoadedStatistic\x12\x44\n\x04stat\x18\x01 \x03(\x0b\x32\x36.th2.data_provider.lw.MessageLoadedStatistic.GroupStat\x1a\x90\x01\n\tGroupStat\x12-\n\x07\x62ook_id\x18\x03 \x01(\x0b\x32\x1c.th2.data_provider.lw.BookId\x12\x45\n\x05group\x18\x01 \x01(\x0b\x32\x36.th2.data_provider.lw.MessageGroupsSearchRequest.Group\x12\r\n\x05\x63ount\x18\x02 \x01(\x04\"\x9d\x03\n\x17\x45ventQueueSearchRequest\x12\x33\n\x0fstart_timestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rend_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12N\n\x0c\x65vent_scopes\x18\x07 \x03(\x0b\x32\x38.th2.data_provider.lw.EventQueueSearchRequest.BookScopes\x12\x30\n\rsync_interval\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x16\n\x0e\x65xternal_queue\x18\x05 \x01(\t\x12\x12\n\nkeep_alive\x18\x06 \x01(\x08\x1al\n\nBookScopes\x12-\n\x07\x62ook_id\x18\x01 \x01(\x0b\x32\x1c.th2.data_provider.lw.BookId\x12/\n\x05scope\x18\x02 \x03(\x0b\x32 .th2.data_provider.lw.EventScope\"\xd6\x01\n\x14\x45ventLoadedStatistic\x12\x42\n\x04stat\x18\x01 \x03(\x0b\x32\x34.th2.data_provider.lw.EventLoadedStatistic.ScopeStat\x1az\n\tScopeStat\x12-\n\x07\x62ook_id\x18\x03 \x01(\x0b\x32\x1c.th2.data_provider.lw.BookId\x12/\n\x05scope\x18\x01 \x01(\x0b\x32 .th2.data_provider.lw.EventScope\x12\r\n\x05\x63ount\x18\x02 \x01(\x04\x32\xfa\x01\n\x11QueueDataProvider\x12z\n\x13SearchMessageGroups\x12\x35.th2.data_provider.lw.MessageGroupsQueueSearchRequest\x1a,.th2.data_provider.lw.MessageLoadedStatistic\x12i\n\x0cSearchEvents\x12-.th2.data_provider.lw.EventQueueSearchRequest\x1a*.th2.data_provider.lw.EventLoadedStatisticB)\n%com.exactpro.th2.dataprovider.lw.grpcP\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'th2_grpc_lw_data_provider.queue_data_provider_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.exactpro.th2.dataprovider.lw.grpcP\001'
  _MESSAGEGROUPSQUEUESEARCHREQUEST._serialized_start=193
  _MESSAGEGROUPSQUEUESEARCHREQUEST._serialized_end=697
  _MESSAGEGROUPSQUEUESEARCHREQUEST_BOOKGROUPS._serialized_start=561
  _MESSAGEGROUPSQUEUESEARCHREQUEST_BOOKGROUPS._serialized_end=691
  _MESSAGELOADEDSTATISTIC._serialized_start=700
  _MESSAGELOADEDSTATISTIC._serialized_end=941
  _MESSAGELOADEDSTATISTIC_GROUPSTAT._serialized_start=797
  _MESSAGELOADEDSTATISTIC_GROUPSTAT._serialized_end=941
  _EVENTQUEUESEARCHREQUEST._serialized_start=944
  _EVENTQUEUESEARCHREQUEST._serialized_end=1357
  _EVENTQUEUESEARCHREQUEST_BOOKSCOPES._serialized_start=1249
  _EVENTQUEUESEARCHREQUEST_BOOKSCOPES._serialized_end=1357
  _EVENTLOADEDSTATISTIC._serialized_start=1360
  _EVENTLOADEDSTATISTIC._serialized_end=1574
  _EVENTLOADEDSTATISTIC_SCOPESTAT._serialized_start=1452
  _EVENTLOADEDSTATISTIC_SCOPESTAT._serialized_end=1574
  _QUEUEDATAPROVIDER._serialized_start=1577
  _QUEUEDATAPROVIDER._serialized_end=1827
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from th2_grpc_lw_data_provider import queue_data_provider_pb2 as th2__grpc__lw__data__provider_dot_queue__data__provider__pb2


class QueueDataProviderStub(object):
    """*
    Service is used to request messages from DB and sent them to specified Queue
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SearchMessageGroups = channel.unary_unary(
                '/th2.data_provider.lw.QueueDataProvider/SearchMessageGroups',
                request_serializer=th2__grpc__lw__data__provider_dot_queue__data__provider__pb2.MessageGroupsQueueSearchRequest.SerializeToString,
                response_deserializer=th2__grpc__lw__data__provider_dot_queue__data__provider__pb2.MessageLoadedStatistic.FromString,
                )
        self.SearchEvents = channel.unary_unary(
                '/th2.data_provider.lw.QueueDataProvider/SearchEvents',
                request_serializer=th2__grpc__lw__data__provider_dot_queue__data__provider__pb2.EventQueueSearchRequest.SerializeToString,
                response_deserializer=th2__grpc__lw__data__provider_dot_queue__data__provider__pb2.EventLoadedStatistic.FromString,
                )


class QueueDataProviderServicer(object):
    """*
    Service is used to request messages from DB and sent them to specified Queue
    """

    def SearchMessageGroups(self, request, context):
        """
        The messages are return within group batches
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SearchEvents(self, request, context):
        """
        Requesting events with the specified interval and sends them to queue
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueueDataProviderServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SearchMessageGroups': grpc.unary_unary_rpc_method_handler(
                    servicer.SearchMessageGroups,
                    request_deserializer=th2__grpc__lw__data__provider_dot_queue__data__provider__pb2.MessageGroupsQueueSearchRequest.FromString,
                    response_serializer=th2__grpc__lw__data__provider_dot_queue__data__provider__pb2.MessageLoadedStatistic.SerializeToString,
            ),
            'SearchEvents': grpc.unary_unary_rpc_method_handler(
                    servicer.SearchEvents,
                    request_deserializer=th2__grpc__lw__data__provider_dot_queue__data__provider__pb2.EventQueueSearchRequest.FromString,
                    response_serializer=th2__grpc__lw__data__provider_dot_queue__data__provider__pb2.EventLoadedStatistic.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'th2.data_provider.lw.QueueDataProvider', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class QueueDataProvider(object):
    """*
    Service is used to request messages from DB and sent them to specified Queue
    """

    @staticmethod
    def SearchMessageGroups(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/th2.data_provider.lw.QueueDataProvider/SearchMessageGroups',
            th2__grpc__lw__data__provider_dot_queue__data__provider__pb2.MessageGroupsQueueSearchRequest.SerializeToString,
            th2__grpc__lw__data__provider_dot_queue__data__provider__pb2.MessageLoadedStatistic.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SearchEvents(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/th2.data_provider.lw.QueueDataProvider/SearchEvents',
            th2__grpc__lw__data__provider_dot_queue__data__provider__pb2.EventQueueSearchRequest.SerializeToString,
            th2__grpc__lw__data__provider_dot_queue__data__provider__pb2.EventLoadedStatistic.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from th2_grpc_common import common_pb2 as th2__grpc__common_dot_common__pb2
from th2_grpc_lw_data_provider import lw_data_provider_pb2 as th2__grpc__lw__data__provider_dot_lw__data__provider__pb2


class DataProviderStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetEvent = channel.unary_unary(
                '/th2.data_provider.lw.DataProvider/GetEvent',
                request_serializer=th2__grpc__common_dot_common__pb2.EventID.SerializeToString,
                response_deserializer=th2__grpc__lw__data__provider_dot_lw__data__provider__pb2.EventResponse.FromString,
                )
        self.GetMessage = channel.unary_unary(
                '/th2.data_provider.lw.DataProvider/GetMessage',
                request_serializer=th2__grpc__common_dot_common__pb2.MessageID.SerializeToString,
                response_deserializer=th2__grpc__lw__data__provider_dot_lw__data__provider__pb2.MessageGroupResponse.FromString,
                )
        self.GetMessageStreams = channel.unary_unary(
                '/th2.data_provider.lw.DataProvider/GetMessageStreams',
                request_serializer=th2__grpc__lw__data__provider_dot_lw__data__provider__pb2.MessageStreamsRequest.SerializeToString,
                response_deserializer=th2__grpc__lw__data__provider_dot_lw__data__provider__pb2.MessageStreamsResponse.FromString,
                )
        self.SearchMessages = channel.unary_stream(
                '/th2.data_provider.lw.DataProvider/SearchMessages',
                request_serializer=th2__grpc__lw__data__provider_dot_lw__data__provider__pb2.MessageSearchRequest.SerializeToString,
                response_deserializer=th2__grpc__lw__data__provider_dot_lw__data__provider__pb2.MessageSearchResponse.FromString,
                )
        self.SearchEvents = channel.unary_stream(
                '/th2.data_provider.lw.DataProvider/SearchEvents',
                request_serializer=th2__grpc__lw__data__provider_dot_lw__data__provider__pb2.EventSearchRequest.SerializeToString,
                response_deserializer=th2__grpc__lw__data__provider_dot_lw__data__provider__pb2.EventSearchResponse.FromString,
                )
        self.SearchMessageGroups = channel.unary_stream(
                '/th2.data_provider.lw.DataProvider/SearchMessageGroups',
                request_serializer=th2__grpc__lw__data__provider_dot_lw__data__provider__pb2.MessageGroupsSearchRequest.SerializeToString,
                response_deserializer=th2__grpc__lw__data__provider_dot_lw__data__provider__pb2.MessageSearchResponse.FromString,
                )
        self.GetBooks = channel.unary_unary(
                '/th2.data_provider.lw.DataProvider/GetBooks',
                request_serializer=th2__grpc__lw__data__provider_dot_lw__data__provider__pb2.BooksRequest.SerializeToString,
                response_deserializer=th2__grpc__lw__data__provider_dot_lw__data__provider__pb2.BooksResponse.FromString,
                )
        self.GetPageInfo = channel.unary_stream(
                '/th2.data_provider.lw.DataProvider/GetPageInfo',
                request_serializer=th2__grpc__lw__data__provider_dot_lw__data__provider__pb2.PageInfoRequest.SerializeToString,
                response_deserializer=th2__grpc__lw__data__provider_dot_lw__data__provider__pb2.PageInfoResponse.FromString,
                )


class DataProviderServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetEvent(self, request, context):
        """returns a single event with the specified id 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMessage(self, request, context):
        """returns a single message with the specified id 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMessageStreams(self, request, context):
        """returns a list of message stream names 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SearchMessages(self, request, context):
        """creates a message stream that matches the filter. 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SearchEvents(self, request, context):
        """creates an event or an event metadata stream that matches the filter. 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SearchMessageGroups(self, request, context):
        """
        Searches for messages groups in specified timestamp
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBooks(self, request, context):
        """Returns the set of books stored in cradle cache
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPageInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DataProviderServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetEvent': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEvent,
                    request_deserializer=th2__grpc__common_dot_common__pb2.EventID.FromString,
                    response_serializer=th2__grpc__lw__data__provider_dot_lw__data__provider__pb2.EventResponse.SerializeToString,
            ),
            'GetMessage': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMessage,
                    request_deserializer=th2__grpc__common_dot_common__pb2.MessageID.FromString,
                    response_serializer=th2__grpc__lw__data__provider_dot_lw__data__provider__pb2.MessageGroupResponse.SerializeToString,
            ),
            'GetMessageStreams': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMessageStreams,
                    request_deserializer=th2__grpc__lw__data__provider_dot_lw__data__provider__pb2.MessageStreamsRequest.FromString,
                    response_serializer=th2__grpc__lw__data__provider_dot_lw__data__provider__pb2.MessageStreamsResponse.SerializeToString,
            ),
            'SearchMessages': grpc.unary_stream_rpc_method_handler(
                    servicer.SearchMessages,
                    request_deserializer=th2__grpc__lw__data__provider_dot_lw__data__provider__pb2.MessageSearchRequest.FromString,
                    response_serializer=th2__grpc__lw__data__provider_dot_lw__data__provider__pb2.MessageSearchResponse.SerializeToString,
            ),
            'SearchEvents': grpc.unary_stream_rpc_method_handler(
                    servicer.SearchEvents,
                    request_deserializer=th2__grpc__lw__data__provider_dot_lw__data__provider__pb2.EventSearchRequest.FromString,
                    response_serializer=th2__grpc__lw__data__provider_dot_lw__data__provider__pb2.EventSearchResponse.SerializeToString,
            ),
            'SearchMessageGroups': grpc.unary_stream_rpc_method_handler(
                    servicer.SearchMessageGroups,
                    request_deserializer=th2__grpc__lw__data__provider_dot_lw__data__provider__pb2.MessageGroupsSearchRequest.FromString,
                    response_serializer=th2__grpc__lw__data__provider_dot_lw__data__provider__pb2.MessageSearchResponse.SerializeToString,
            ),
            'GetBooks': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBooks,
                    request_deserializer=th2__grpc__lw__data__provider_dot_lw__data__provider__pb2.BooksRequest.FromString,
                    response_serializer=th2__grpc__lw__data__provider_dot_lw__data__provider__pb2.BooksResponse.SerializeToString,
            ),
            'GetPageInfo': grpc.unary_stream_rpc_method_handler(
                    servicer.GetPageInfo,
                    request_deserializer=th2__grpc__lw__data__provider_dot_lw__data__provider__pb2.PageInfoRequest.FromString,
                    response_serializer=th2__grpc__lw__data__provider_dot_lw__data__provider__pb2.PageInfoResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'th2.data_provider.lw.DataProvider', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DataProvider(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetEvent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/th2.data_provider.lw.DataProvider/GetEvent',
            th2__grpc__common_dot_common__pb2.EventID.SerializeToString,
            th2__grpc__lw__data__provider_dot_lw__data__provider__pb2.EventResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMessage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/th2.data_provider.lw.DataProvider/GetMessage',
            th2__grpc__common_dot_common__pb2.MessageID.SerializeToString,
            th2__grpc__lw__data__provider_dot_lw__data__provider__pb2.MessageGroupResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMessageStreams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/th2.data_provider.lw.DataProvider/GetMessageStreams',
            th2__grpc__lw__data__provider_dot_lw__data__provider__pb2.MessageStreamsRequest.SerializeToString,
            th2__grpc__lw__data__provider_dot_lw__data__provider__pb2.MessageStreamsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SearchMessages(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/th2.data_provider.lw.DataProvider/SearchMessages',
            th2__grpc__lw__data__provider_dot_lw__data__provider__pb2.MessageSearchRequest.SerializeToString,
            th2__grpc__lw__data__provider_dot_lw__data__provider__pb2.MessageSearchResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SearchEvents(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/th2.data_provider.lw.DataProvider/SearchEvents',
            th2__grpc__lw__data__provider_dot_lw__data__provider__pb2.EventSearchRequest.SerializeToString,
            th2__grpc__lw__data__provider_dot_lw__data__provider__pb2.EventSearchResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SearchMessageGroups(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/th2.data_provider.lw.DataProvider/SearchMessageGroups',
            th2__grpc__lw__data__provider_dot_lw__data__provider__pb2.MessageGroupsSearchRequest.SerializeToString,
            th2__grpc__lw__data__provider_dot_lw__data__provider__pb2.MessageSearchResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBooks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/th2.data_provider.lw.DataProvider/GetBooks',
            th2__grpc__lw__data__provider_dot_lw__data__provider__pb2.BooksRequest.SerializeToString,
            th2__grpc__lw__data__provider_dot_lw__data__provider__pb2.BooksResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPageInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/th2.data_provider.lw.DataProvider/GetPageInfo',
            th2__grpc__lw__data__provider_dot_lw__data__provider__pb2.PageInfoRequest.SerializeToString,
            th2__grpc__lw__data__provider_dot_lw__data__provider__pb2.PageInfoResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import google.protobuf.wrappers_pb2
import th2_grpc_common.common_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _TimeRelation:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _TimeRelationEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TimeRelation.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NEXT: _TimeRelation.ValueType  # 0
    PREVIOUS: _TimeRelation.ValueType  # 1
class TimeRelation(_TimeRelation, metaclass=_TimeRelationEnumTypeWrapper):
    pass

NEXT: TimeRelation.ValueType  # 0
PREVIOUS: TimeRelation.ValueType  # 1
global___TimeRelation = TimeRelation


class EventScope(google.protobuf.message.Message):
    """The scope for events to request"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NAME_FIELD_NUMBER: builtins.int
    name: typing.Text
    def __init__(self,
        *,
        name: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name",b"name"]) -> None: ...
global___EventScope = EventScope

class BookId(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NAME_FIELD_NUMBER: builtins.int
    name: typing.Text
    """Name of the book to request data from"""

    def __init__(self,
        *,
        name: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name",b"name"]) -> None: ...
global___BookId = BookId

class MessageGroupsSearchRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class Group(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        NAME_FIELD_NUMBER: builtins.int
        name: typing.Text
        def __init__(self,
            *,
            name: typing.Text = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["name",b"name"]) -> None: ...

    START_TIMESTAMP_FIELD_NUMBER: builtins.int
    END_TIMESTAMP_FIELD_NUMBER: builtins.int
    BOOK_ID_FIELD_NUMBER: builtins.int
    MESSAGE_GROUP_FIELD_NUMBER: builtins.int
    SORT_FIELD_NUMBER: builtins.int
    RAW_ONLY_FIELD_NUMBER: builtins.int
    KEEP_OPEN_FIELD_NUMBER: builtins.int
    @property
    def start_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def end_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def book_id(self) -> global___BookId: ...
    @property
    def message_group(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MessageGroupsSearchRequest.Group]: ...
    @property
    def sort(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    raw_only: builtins.bool
    keep_open: builtins.bool
    def __init__(self,
        *,
        start_timestamp: typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        end_timestamp: typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        book_id: typing.Optional[global___BookId] = ...,
        message_group: typing.Optional[typing.Iterable[global___MessageGroupsSearchRequest.Group]] = ...,
        sort: typing.Optional[google.protobuf.wrappers_pb2.BoolValue] = ...,
        raw_only: builtins.bool = ...,
        keep_open: builtins.bool = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["book_id",b"book_id","end_timestamp",b"end_timestamp","sort",b"sort","start_timestamp",b"start_timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["book_id",b"book_id","end_timestamp",b"end_timestamp","keep_open",b"keep_open","message_group",b"message_group","raw_only",b"raw_only","sort",b"sort","start_timestamp",b"start_timestamp"]) -> None: ...
global___MessageGroupsSearchRequest = MessageGroupsSearchRequest

class MessageStreamsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BOOK_ID_FIELD_NUMBER: builtins.int
    @property
    def book_id(self) -> global___BookId: ...
    def __init__(self,
        *,
        book_id: typing.Optional[global___BookId] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["book_id",b"book_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["book_id",b"book_id"]) -> None: ...
global___MessageStreamsRequest = MessageStreamsRequest

class EventResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    EVENT_ID_FIELD_NUMBER: builtins.int
    PARENT_EVENT_ID_FIELD_NUMBER: builtins.int
    BATCH_ID_FIELD_NUMBER: builtins.int
    IS_BATCHED_FIELD_NUMBER: builtins.int
    START_TIMESTAMP_FIELD_NUMBER: builtins.int
    END_TIMESTAMP_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    EVENT_NAME_FIELD_NUMBER: builtins.int
    EVENT_TYPE_FIELD_NUMBER: builtins.int
    BODY_FIELD_NUMBER: builtins.int
    ATTACHED_MESSAGE_ID_FIELD_NUMBER: builtins.int
    @property
    def event_id(self) -> th2_grpc_common.common_pb2.EventID:
        """Current event id"""
        pass
    @property
    def parent_event_id(self) -> th2_grpc_common.common_pb2.EventID:
        """Event id of a parent event. It is absent for root event"""
        pass
    @property
    def batch_id(self) -> th2_grpc_common.common_pb2.EventID:
        """Event id of a parent event. It is absent for root event"""
        pass
    is_batched: builtins.bool
    """Flag indicating that the event is in batch"""

    @property
    def start_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def end_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """May be absent."""
        pass
    status: th2_grpc_common.common_pb2.EventStatus.ValueType
    """Aggregated status of current and children events which sync written."""

    event_name: typing.Text
    event_type: typing.Text
    """May be absent."""

    body: builtins.bytes
    """May be absent."""

    @property
    def attached_message_id(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[th2_grpc_common.common_pb2.MessageID]:
        """ids of messages linked to this event"""
        pass
    def __init__(self,
        *,
        event_id: typing.Optional[th2_grpc_common.common_pb2.EventID] = ...,
        parent_event_id: typing.Optional[th2_grpc_common.common_pb2.EventID] = ...,
        batch_id: typing.Optional[th2_grpc_common.common_pb2.EventID] = ...,
        is_batched: builtins.bool = ...,
        start_timestamp: typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        end_timestamp: typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        status: th2_grpc_common.common_pb2.EventStatus.ValueType = ...,
        event_name: typing.Text = ...,
        event_type: typing.Text = ...,
        body: builtins.bytes = ...,
        attached_message_id: typing.Optional[typing.Iterable[th2_grpc_common.common_pb2.MessageID]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["batch_id",b"batch_id","end_timestamp",b"end_timestamp","event_id",b"event_id","parent_event_id",b"parent_event_id","start_timestamp",b"start_timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attached_message_id",b"attached_message_id","batch_id",b"batch_id","body",b"body","end_timestamp",b"end_timestamp","event_id",b"event_id","event_name",b"event_name","event_type",b"event_type","is_batched",b"is_batched","parent_event_id",b"parent_event_id","start_timestamp",b"start_timestamp","status",b"status"]) -> None: ...
global___EventResponse = EventResponse

class MessageGroupItem(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MESSAGE_FIELD_NUMBER: builtins.int
    MATCH_FIELD_NUMBER: builtins.int
    @property
    def message(self) -> th2_grpc_common.common_pb2.Message: ...
    match: builtins.bool
    def __init__(self,
        *,
        message: typing.Optional[th2_grpc_common.common_pb2.Message] = ...,
        match: builtins.bool = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["message",b"message"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["match",b"match","message",b"message"]) -> None: ...
global___MessageGroupItem = MessageGroupItem

class MessageGroupResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class MessagePropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: typing.Text
        value: typing.Text
        def __init__(self,
            *,
            key: typing.Text = ...,
            value: typing.Text = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key",b"key","value",b"value"]) -> None: ...

    MESSAGE_ID_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    MESSAGE_PROPERTIES_FIELD_NUMBER: builtins.int
    BODY_RAW_FIELD_NUMBER: builtins.int
    ATTACHED_EVENT_ID_FIELD_NUMBER: builtins.int
    MESSAGE_ITEM_FIELD_NUMBER: builtins.int
    @property
    def message_id(self) -> th2_grpc_common.common_pb2.MessageID:
        """Message id should be unique in session"""
        pass
    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Message creation timestamp. Deprecated. Moved to MessageID"""
        pass
    @property
    def message_properties(self) -> google.protobuf.internal.containers.ScalarMap[typing.Text, typing.Text]:
        """Additional properties for the source raw message"""
        pass
    body_raw: builtins.bytes
    @property
    def attached_event_id(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[th2_grpc_common.common_pb2.EventID]:
        """ids of events linked to this message group"""
        pass
    @property
    def message_item(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MessageGroupItem]:
        """May be absent."""
        pass
    def __init__(self,
        *,
        message_id: typing.Optional[th2_grpc_common.common_pb2.MessageID] = ...,
        timestamp: typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        message_properties: typing.Optional[typing.Mapping[typing.Text, typing.Text]] = ...,
        body_raw: builtins.bytes = ...,
        attached_event_id: typing.Optional[typing.Iterable[th2_grpc_common.common_pb2.EventID]] = ...,
        message_item: typing.Optional[typing.Iterable[global___MessageGroupItem]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["message_id",b"message_id","timestamp",b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attached_event_id",b"attached_event_id","body_raw",b"body_raw","message_id",b"message_id","message_item",b"message_item","message_properties",b"message_properties","timestamp",b"timestamp"]) -> None: ...
global___MessageGroupResponse = MessageGroupResponse

class FilterName(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NAME_FIELD_NUMBER: builtins.int
    name: typing.Text
    def __init__(self,
        *,
        name: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name",b"name"]) -> None: ...
global___FilterName = FilterName

class Filter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NAME_FIELD_NUMBER: builtins.int
    NEGATIVE_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    CONJUNCT_FIELD_NUMBER: builtins.int
    @property
    def name(self) -> global___FilterName: ...
    negative: builtins.bool
    @property
    def value(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    conjunct: builtins.bool
    def __init__(self,
        *,
        name: typing.Optional[global___FilterName] = ...,
        negative: builtins.bool = ...,
        value: typing.Optional[typing.Iterable[typing.Text]] = ...,
        conjunct: builtins.bool = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["name",b"name"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["conjunct",b"conjunct","name",b"name","negative",b"negative","value",b"value"]) -> None: ...
global___Filter = Filter

class EventSearchRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    START_TIMESTAMP_FIELD_NUMBER: builtins.int
    END_TIMESTAMP_FIELD_NUMBER: builtins.int
    PARENT_EVENT_FIELD_NUMBER: builtins.int
    SEARCH_DIRECTION_FIELD_NUMBER: builtins.int
    RESULT_COUNT_LIMIT_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    BOOK_ID_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    @property
    def start_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """unix timestamp - Sets the search starting point. One of the 'start_timestamp' or 'resume_from_id' must not absent"""
        pass
    @property
    def end_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """unix timestamp - Sets the timestamp to which the search will be performed, starting with 'start_timestamp'. When 'search_direction' is previous, end_timestamp must be less than start_timestamp. By default it is absent (the search is carried out endlessly into the past or into the future)."""
        pass
    @property
    def parent_event(self) -> th2_grpc_common.common_pb2.EventID:
        """Match events to the specified parent. Only the immediate children of the specified event will be returned."""
        pass
    search_direction: global___TimeRelation.ValueType
    """Sets the lookup direction. Can be used for pagination. Set by default to NEXT."""

    @property
    def result_count_limit(self) -> google.protobuf.wrappers_pb2.Int32Value:
        """Sets the maximum amount of events to return. By default it is absent (unlimited)."""
        pass
    @property
    def filter(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Filter]:
        """List of event search filters. (See 'search/sse/events' HTTP method https://github.com/th2-net/th2-rpt-data-provider)"""
        pass
    @property
    def book_id(self) -> global___BookId: ...
    @property
    def scope(self) -> global___EventScope: ...
    def __init__(self,
        *,
        start_timestamp: typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        end_timestamp: typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        parent_event: typing.Optional[th2_grpc_common.common_pb2.EventID] = ...,
        search_direction: global___TimeRelation.ValueType = ...,
        result_count_limit: typing.Optional[google.protobuf.wrappers_pb2.Int32Value] = ...,
        filter: typing.Optional[typing.Iterable[global___Filter]] = ...,
        book_id: typing.Optional[global___BookId] = ...,
        scope: typing.Optional[global___EventScope] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["book_id",b"book_id","end_timestamp",b"end_timestamp","parent_event",b"parent_event","result_count_limit",b"result_count_limit","scope",b"scope","start_timestamp",b"start_timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["book_id",b"book_id","end_timestamp",b"end_timestamp","filter",b"filter","parent_event",b"parent_event","result_count_limit",b"result_count_limit","scope",b"scope","search_direction",b"search_direction","start_timestamp",b"start_timestamp"]) -> None: ...
global___EventSearchRequest = EventSearchRequest

class EventSearchResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    EVENT_FIELD_NUMBER: builtins.int
    @property
    def event(self) -> global___EventResponse: ...
    def __init__(self,
        *,
        event: typing.Optional[global___EventResponse] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["data",b"data","event",b"event"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data",b"data","event",b"event"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["data",b"data"]) -> typing.Optional[typing_extensions.Literal["event"]]: ...
global___EventSearchResponse = EventSearchResponse

class MessageSearchRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    START_TIMESTAMP_FIELD_NUMBER: builtins.int
    END_TIMESTAMP_FIELD_NUMBER: builtins.int
    SEARCH_DIRECTION_FIELD_NUMBER: builtins.int
    RESULT_COUNT_LIMIT_FIELD_NUMBER: builtins.int
    STREAM_FIELD_NUMBER: builtins.int
    KEEP_OPEN_FIELD_NUMBER: builtins.int
    STREAM_POINTER_FIELD_NUMBER: builtins.int
    RESPONSE_FORMATS_FIELD_NUMBER: builtins.int
    BOOK_ID_FIELD_NUMBER: builtins.int
    @property
    def start_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """unix timestamp - Sets the search starting point. One of the 'start_timestamp' or 'resume_from_id' or 'message_id' must not absent"""
        pass
    @property
    def end_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """unix timestamp - Sets the timestamp to which the search will be performed, starting with 'start_timestamp'. When search_direction is 'previous', 'end_timestamp' must be less than 'start_timestamp'. By default it is absent (the search is carried out endlessly into the past or into the future)."""
        pass
    search_direction: global___TimeRelation.ValueType
    """Sets the lookup direction. Can be used for pagination. Set by default to NEXT."""

    @property
    def result_count_limit(self) -> google.protobuf.wrappers_pb2.Int32Value:
        """Sets the maximum amount of messages to return. By default it is absent (unlimited)"""
        pass
    @property
    def stream(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MessageStream]:
        """Sets the stream names and directions to search in. Case-sensitive. Required."""
        pass
    @property
    def keep_open(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """ If the search has reached the current moment, it is necessary to wait further for the appearance of new data. Set by default to false."""
        pass
    @property
    def stream_pointer(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MessageStreamPointer]:
        """List of stream pointers to restore the search from. start_timestamp will be ignored if this parameter is specified. By default it is absent."""
        pass
    @property
    def response_formats(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]:
        """List of possible response formats (e.g. PARSED or BASE_64)"""
        pass
    @property
    def book_id(self) -> global___BookId: ...
    def __init__(self,
        *,
        start_timestamp: typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        end_timestamp: typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        search_direction: global___TimeRelation.ValueType = ...,
        result_count_limit: typing.Optional[google.protobuf.wrappers_pb2.Int32Value] = ...,
        stream: typing.Optional[typing.Iterable[global___MessageStream]] = ...,
        keep_open: typing.Optional[google.protobuf.wrappers_pb2.BoolValue] = ...,
        stream_pointer: typing.Optional[typing.Iterable[global___MessageStreamPointer]] = ...,
        response_formats: typing.Optional[typing.Iterable[typing.Text]] = ...,
        book_id: typing.Optional[global___BookId] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["book_id",b"book_id","end_timestamp",b"end_timestamp","keep_open",b"keep_open","result_count_limit",b"result_count_limit","start_timestamp",b"start_timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["book_id",b"book_id","end_timestamp",b"end_timestamp","keep_open",b"keep_open","response_formats",b"response_formats","result_count_limit",b"result_count_limit","search_direction",b"search_direction","start_timestamp",b"start_timestamp","stream",b"stream","stream_pointer",b"stream_pointer"]) -> None: ...
global___MessageSearchRequest = MessageSearchRequest

class MessageSearchResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MESSAGE_FIELD_NUMBER: builtins.int
    MESSAGE_STREAM_POINTERS_FIELD_NUMBER: builtins.int
    @property
    def message(self) -> global___MessageGroupResponse: ...
    @property
    def message_stream_pointers(self) -> global___MessageStreamPointers: ...
    def __init__(self,
        *,
        message: typing.Optional[global___MessageGroupResponse] = ...,
        message_stream_pointers: typing.Optional[global___MessageStreamPointers] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["data",b"data","message",b"message","message_stream_pointers",b"message_stream_pointers"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data",b"data","message",b"message","message_stream_pointers",b"message_stream_pointers"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["data",b"data"]) -> typing.Optional[typing_extensions.Literal["message","message_stream_pointers"]]: ...
global___MessageSearchResponse = MessageSearchResponse

class MessageStreamPointers(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MESSAGE_STREAM_POINTER_FIELD_NUMBER: builtins.int
    @property
    def message_stream_pointer(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MessageStreamPointer]: ...
    def __init__(self,
        *,
        message_stream_pointer: typing.Optional[typing.Iterable[global___MessageStreamPointer]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["message_stream_pointer",b"message_stream_pointer"]) -> None: ...
global___MessageStreamPointers = MessageStreamPointers

class MessageStreamPointer(google.protobuf.message.Message):
    """This object contains the data of the last message in the stream on which
    the search has stopped, it is necessary to continue the search from the same point
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MESSAGE_STREAM_FIELD_NUMBER: builtins.int
    LAST_ID_FIELD_NUMBER: builtins.int
    @property
    def message_stream(self) -> global___MessageStream: ...
    @property
    def last_id(self) -> th2_grpc_common.common_pb2.MessageID:
        """Might be absent if the stream has no messages"""
        pass
    def __init__(self,
        *,
        message_stream: typing.Optional[global___MessageStream] = ...,
        last_id: typing.Optional[th2_grpc_common.common_pb2.MessageID] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_id",b"last_id","message_stream",b"message_stream"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["last_id",b"last_id","message_stream",b"message_stream"]) -> None: ...
global___MessageStreamPointer = MessageStreamPointer

class MessageStream(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NAME_FIELD_NUMBER: builtins.int
    DIRECTION_FIELD_NUMBER: builtins.int
    name: typing.Text
    """Case sensitive. Required."""

    direction: th2_grpc_common.common_pb2.Direction.ValueType
    """Required."""

    def __init__(self,
        *,
        name: typing.Text = ...,
        direction: th2_grpc_common.common_pb2.Direction.ValueType = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["direction",b"direction","name",b"name"]) -> None: ...
global___MessageStream = MessageStream

class MessageStreamsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MESSAGE_STREAM_FIELD_NUMBER: builtins.int
    @property
    def message_stream(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MessageStream]: ...
    def __init__(self,
        *,
        message_stream: typing.Optional[typing.Iterable[global___MessageStream]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["message_stream",b"message_stream"]) -> None: ...
global___MessageStreamsResponse = MessageStreamsResponse

class BooksRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___BooksRequest = BooksRequest

class BooksResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BOOK_IDS_FIELD_NUMBER: builtins.int
    @property
    def book_ids(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___BookId]: ...
    def __init__(self,
        *,
        book_ids: typing.Optional[typing.Iterable[global___BookId]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["book_ids",b"book_ids"]) -> None: ...
global___BooksResponse = BooksResponse

class PageInfoRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BOOK_ID_FIELD_NUMBER: builtins.int
    START_TIMESTAMP_FIELD_NUMBER: builtins.int
    END_TIMESTAMP_FIELD_NUMBER: builtins.int
    RESULT_LIMIT_FIELD_NUMBER: builtins.int
    @property
    def book_id(self) -> global___BookId: ...
    @property
    def start_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def end_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def result_limit(self) -> google.protobuf.wrappers_pb2.Int32Value: ...
    def __init__(self,
        *,
        book_id: typing.Optional[global___BookId] = ...,
        start_timestamp: typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        end_timestamp: typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        result_limit: typing.Optional[google.protobuf.wrappers_pb2.Int32Value] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["book_id",b"book_id","end_timestamp",b"end_timestamp","result_limit",b"result_limit","start_timestamp",b"start_timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["book_id",b"book_id","end_timestamp",b"end_timestamp","result_limit",b"result_limit","start_timestamp",b"start_timestamp"]) -> None: ...
global___PageInfoRequest = PageInfoRequest

class PageInfoResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ID_FIELD_NUMBER: builtins.int
    COMMENT_FIELD_NUMBER: builtins.int
    STARTED_FIELD_NUMBER: builtins.int
    ENDED_FIELD_NUMBER: builtins.int
    UPDATED_FIELD_NUMBER: builtins.int
    REMOVED_FIELD_NUMBER: builtins.int
    @property
    def id(self) -> global___PageId: ...
    @property
    def comment(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def started(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def ended(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def updated(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def removed(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(self,
        *,
        id: typing.Optional[global___PageId] = ...,
        comment: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        started: typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        ended: typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        updated: typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        removed: typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["comment",b"comment","ended",b"ended","id",b"id","removed",b"removed","started",b"started","updated",b"updated"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["comment",b"comment","ended",b"ended","id",b"id","removed",b"removed","started",b"started","updated",b"updated"]) -> None: ...
global___PageInfoResponse = PageInfoResponse

class PageId(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BOOK_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def book_id(self) -> global___BookId: ...
    name: typing.Text
    def __init__(self,
        *,
        book_id: typing.Optional[global___BookId] = ...,
        name: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["book_id",b"book_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["book_id",b"book_id","name",b"name"]) -> None: ...
global___PageId = PageId
